#[repr(u8)]pub enum LayerSemantics {
None = 0,
IsTombstone = 1,
IsSupersedeLocal = 2,
IsSupersedeTree = 3,
}Expand description
Layer semantics values for layered keys (Windows 10 RS1+).
Variants
None = 0
Key node and parent key nodes can be included in the layered key.
IsTombstone = 1
Tombstone key node: cannot be included in layered key (no class name, no subkeys, no values).
IsSupersedeLocal = 2
Key node can be included, but parent key nodes cannot.
IsSupersedeTree = 3
Key node can be included, parent key nodes cannot; child key nodes must have same value.